@@ -1,10 +1,10 @@
 import torch
 import torch.nn as nn
 import torch.nn.functional as F
+from mmcv.runner import auto_fp16, force_fp32
 from torch.nn.modules.utils import _pair
 
-from mmdet.core import (auto_fp16, build_bbox_coder, force_fp32, multi_apply,
-                        multiclass_nms)
+from mmdet.core import build_bbox_coder, multi_apply, multiclass_nms
 from mmdet.models.builder import HEADS, build_loss
 from mmdet.models.losses import accuracy
 
@@ -181,7 +181,7 @@ class BBoxHead(nn.Module):
                     avg_factor=bbox_targets.size(0),
                     reduction_override=reduction_override)
             else:
-                losses['loss_bbox'] = bbox_pred.sum() * 0
+                losses['loss_bbox'] = bbox_pred[pos_inds].sum()
         return losses
 
     @force_fp32(apply_to=('cls_score', 'bbox_pred'))
